/**
 * Features:
 * - caching with tags for tag based invalidation
 * - control whether or not to throw on error
 */
export interface Cache {
    get<T>(key: string, options?: CacheOptions): Promise<T | null>;
    set(key: string, data: any, tags: string[], options?: SetCacheOptions): Promise<void>;
    set(key: string, data: any, options?: SetCacheOptions): Promise<void>;
    delete(key: string, options?: CacheOptions): Promise<void>;
    invalidateTags: (tags: string[], options?: CacheOptions) => Promise<void>;
    flushAll: () => Promise<void>;
}
export interface CacheOptions {
    responseTimeoutInMillis?: number;
    throwOnError?: boolean;
}
export interface SetCacheOptions extends CacheOptions {
    ttlInSecs?: number;
}
