import Redis from 'ioredis';
import { Cache, CacheOptions } from './Cache';
/**
 * Features:
 * - caching with tags for tag based invalidation
 * - control whether or not to throw on error
 *
 * defaults:
 *  - prefix: no prefix
 *  - defaultResponseTimeoutInMillis: 2000
 *  - defaultExpirationInSecs: 3600
 */
export declare class RedisCache implements Cache {
    constructor(config: RedisConfig);
    redis: Redis.Redis;
    defaultResponseTimeoutInMillis: number;
    defaultExpirationInSecs: number;
    get<T>(key: string, options?: CacheOptions): Promise<T | null>;
    set(key: string, data: any, param3?: any, param4?: any): Promise<void>;
    delete(key: string, options?: CacheOptions): Promise<void>;
    invalidateTags(tags: string[], options?: CacheOptions): Promise<void>;
    flushAll(): Promise<void>;
}
interface RedisConfig {
    port: number;
    host: string;
    prefix?: string;
    defaultExpirationInSecs?: number;
    defaultResponseTimeoutInMillis?: number;
}
export {};
