/// <reference types="node" />
import { Logger } from '../Logger';
import { Router } from '../Router';
import * as oracledb from 'oracledb';
import { SecretsManager } from '../SecretsManager';
import { RequestContext } from '../RequestContext';
import { AsyncLocalStorage } from 'async_hooks';
import { APIGatewayProxyHandler } from 'aws-lambda';
export declare class HandlerFactory {
    private router;
    private logger;
    private asyncContext;
    private config;
    private secretsManager?;
    private oracleDb?;
    private oracleDbConfig?;
    constructor(router: Router, logger: Logger, asyncContext: AsyncLocalStorage<RequestContext>, config: Config, secretsManager?: SecretsManager | undefined, oracleDb?: typeof oracledb | undefined, oracleDbConfig?: OracleDbConfig | undefined);
    private databaseSecret;
    getHandler(): APIGatewayProxyHandler;
    /**
     * forceSampling do not follow opentelemetry specifications (nor head-based sampling)
     * but is necessary to meet our requirements
     */
    private getContextualizedSpan;
    private getHeaderWithForcedSampling;
    private getIdentity;
    private handle;
}
export interface OracleDbConfig {
    createPool: boolean;
    oracleDbSecretName?: string;
    connectString?: string;
    poolIncrement?: number;
    poolMax?: number;
    poolMin?: number;
}
interface Config {
    serviceName: string;
    useOracleDb: boolean;
    tracingFlushTimeoutInMs: number;
}
export {};
