"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HandlerFactory = void 0;
const delay_1 = __importDefault(require("delay"));
const caseless_1 = __importDefault(require("caseless"));
const lodash_1 = require("lodash");
const autobind_decorator_1 = require("autobind-decorator");
const perf_hooks_1 = require("perf_hooks");
const uuid_1 = require("uuid");
const propagator_jaeger_1 = require("@opentelemetry/propagator-jaeger");
const api_1 = __importStar(require("@opentelemetry/api"));
class HandlerFactory {
    constructor(router, logger, asyncContext, config, secretsManager, oracleDb, oracleDbConfig) {
        this.router = router;
        this.logger = logger;
        this.asyncContext = asyncContext;
        this.config = config;
        this.secretsManager = secretsManager;
        this.oracleDb = oracleDb;
        this.oracleDbConfig = oracleDbConfig;
        this.databaseSecret = undefined;
    }
    getHandler() {
        return async (request, context) => {
            /** @todo allow forcing trace by route and method */
            const span = this.getContextualizedSpan(request.headers, false);
            span.setAttribute('requestId', request.requestContext.requestId);
            const response = await new Promise((resolve, reject) => {
                api_1.default.context.with(api_1.setSpan(api_1.default.context.active(), span), async () => {
                    const identity = this.getIdentity(request);
                    this.asyncContext.run({
                        sourceIp: request.requestContext?.identity?.sourceIp,
                        requestId: request.requestContext.requestId,
                        identitySummary: identity,
                        identityData: identity,
                        authMethod: 'apikey',
                        path: request.path,
                        method: request.httpMethod,
                        traceId: span.context().traceId,
                        app: this.config.serviceName,
                    }, () => this.handle(request, context).then(resolve).catch(reject));
                });
            });
            span.end();
            // In order to allow sampled span integration before lambda freezing
            if (span.context().traceFlags === 1)
                await delay_1.default(this.config.tracingFlushTimeoutInMs);
            return response;
        };
    }
    /**
     * forceSampling do not follow opentelemetry specifications (nor head-based sampling)
     * but is necessary to meet our requirements
     */
    getContextualizedSpan(headers, forceSampling) {
        const tracer = api_1.default.trace.getTracer('ocm');
        const overridenHeaders = lodash_1.cloneDeep(headers);
        if (forceSampling) {
            const uberTraceId = caseless_1.default(headers).get('uber-trace-id');
            overridenHeaders['uber-trace-id'] = this.getHeaderWithForcedSampling(uberTraceId);
        }
        const ctx = new propagator_jaeger_1.JaegerHttpTracePropagator().extract(api_1.default.context.active(), overridenHeaders, api_1.defaultTextMapGetter);
        return tracer.startSpan(this.config.serviceName, undefined, ctx);
    }
    getHeaderWithForcedSampling(uberTracingHeader) {
        const traceId = uuid_1.v4().replace(/-/g, '');
        const spanId = uuid_1.v4().replace(/-/g, '').substring(0, 16);
        const uberHeader = `${traceId}:${spanId}:0:01`;
        if (uberTracingHeader) {
            const components = uberTracingHeader.split(':');
            if (components.length !== 4)
                return uberHeader;
            const [_traceId, _spanId, , flags] = components;
            const traceFlags = flags.match(/^[0-9a-f]{2}$/i) ? parseInt(flags) & 1 : 1;
            if (traceFlags === 1)
                return uberTracingHeader;
            const traceId = _traceId.padStart(32, '0');
            const spanId = _spanId.padStart(16, '0');
            return `${traceId}:${spanId}:0:01`;
        }
        return uberHeader;
    }
    getIdentity(request) {
        const apiKey = request.requestContext?.identity?.apiKey;
        if (apiKey) {
            const startOfApiKey = apiKey.substring(0, 5);
            return `apikey ${startOfApiKey}*****`;
        }
        return 'unknown';
    }
    async handle(request, context) {
        const start = perf_hooks_1.performance.now();
        if (this.config.useOracleDb && this.oracleDbConfig?.createPool) {
            const { oracleDbSecretName } = this.oracleDbConfig;
            if (!oracleDbSecretName)
                throw new TypeError('No oracleDb secret name specified');
            if (!this.secretsManager)
                throw new TypeError('No secrets manager instance provided');
            if (!this.oracleDb)
                throw new TypeError('No OracleDB driver provided');
            if (!this.databaseSecret) {
                this.databaseSecret = await this.secretsManager.get(oracleDbSecretName);
            }
            try {
                this.oracleDb.getPool();
            }
            catch (e) {
                if (e.message.includes('NJS-047')) {
                    const { password, user } = this.databaseSecret;
                    const { poolIncrement, poolMax, poolMin, connectString } = this.oracleDbConfig;
                    await this.oracleDb.createPool({
                        connectString,
                        user,
                        password,
                        poolIncrement: poolIncrement ?? 1,
                        poolMax: poolMax ?? 3,
                        poolMin: poolMin ?? 0,
                    });
                }
                else {
                    this.logger.error(e.message);
                }
            }
        }
        const res = await this.router.route(request, context);
        const end = perf_hooks_1.performance.now();
        const executionTimeInMs = end - start;
        this.logger.info({
            category: 'EXECUTION_SUMMARY',
            label: 'DURATION IN MILLIS',
            statusCode: String(res.statusCode),
            value: executionTimeInMs,
        });
        return res;
    }
}
__decorate([
    autobind_decorator_1.boundMethod
], HandlerFactory.prototype, "getHandler", null);
__decorate([
    autobind_decorator_1.boundMethod
], HandlerFactory.prototype, "getContextualizedSpan", null);
__decorate([
    autobind_decorator_1.boundMethod
], HandlerFactory.prototype, "getHeaderWithForcedSampling", null);
__decorate([
    autobind_decorator_1.boundMethod
], HandlerFactory.prototype, "getIdentity", null);
__decorate([
    autobind_decorator_1.boundMethod
], HandlerFactory.prototype, "handle", null);
exports.HandlerFactory = HandlerFactory;
