"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StructuredLogger = void 0;
const autobind_decorator_1 = require("autobind-decorator");
const logLevelMap = {
    DEBUG: 1,
    INFO: 2,
    WARN: 3,
    ERROR: 4,
};
class StructuredLogger {
    constructor(requestContextRegistry, configs) {
        this.requestContextRegistry = requestContextRegistry;
        this.configs = configs;
    }
    write(level, log) {
        if (!log || (typeof log !== 'string' && typeof log !== 'object'))
            return;
        const configuredLevel = this.configs.level || 'DEBUG';
        if (logLevelMap[level] < logLevelMap[configuredLevel])
            return;
        const context = this.requestContextRegistry.getStore();
        const { requestId, authMethod, identitySummary, sourceIp, traceId } = context || {};
        let logData = {
            timestamp: new Date().toISOString(),
            level,
            requestId,
            authMethod,
            identitySummary,
            sourceIp,
            traceId,
        };
        if (typeof log === 'string') {
            logData.message = log;
        }
        else {
            logData = {
                ...log,
                ...logData,
            };
        }
        for (const key of Object.keys(logData)) {
            if (typeof logData[key] !== 'string' && typeof logData[key] !== 'number') {
                logData[key] = JSON.stringify(logData[key]);
            }
        }
        const stringEnforcedFields = [
            'app',
            'agent',
            'namespace',
            'method',
            'path',
            'resourceId',
            'statusCode',
            'category',
            'action',
            'label',
            'stack',
            'message',
            'data',
        ];
        const numericEnforcedFields = ['value'];
        for (const key of stringEnforcedFields) {
            if (logData[key] !== undefined && typeof logData[key] !== 'string') {
                logData[key] = JSON.stringify(logData[key]);
            }
        }
        for (const key of numericEnforcedFields) {
            if (logData[key] !== undefined && typeof logData[key] !== 'number' && !isNaN(Number(logData[key]))) {
                logData[key] = Number(logData[key]);
            }
        }
        const logEntry = this.configs.prettyPrint ? JSON.stringify(logData, null, 2) : JSON.stringify(logData);
        const loggers = {
            DEBUG: console.debug,
            INFO: console.info,
            WARN: console.warn,
            ERROR: console.error,
        };
        loggers[level](logEntry);
    }
    log(log) {
        this.write('INFO', log);
    }
    info(log) {
        this.write('INFO', log);
    }
    debug(log) {
        this.write('DEBUG', log);
    }
    warn(log) {
        this.write('WARN', log);
    }
    error(log) {
        this.write('ERROR', log);
    }
}
__decorate([
    autobind_decorator_1.boundMethod
], StructuredLogger.prototype, "write", null);
__decorate([
    autobind_decorator_1.boundMethod
], StructuredLogger.prototype, "log", null);
__decorate([
    autobind_decorator_1.boundMethod
], StructuredLogger.prototype, "info", null);
__decorate([
    autobind_decorator_1.boundMethod
], StructuredLogger.prototype, "debug", null);
__decorate([
    autobind_decorator_1.boundMethod
], StructuredLogger.prototype, "warn", null);
__decorate([
    autobind_decorator_1.boundMethod
], StructuredLogger.prototype, "error", null);
exports.StructuredLogger = StructuredLogger;
