"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AWSSecretsManager = void 0;
const delay_1 = __importDefault(require("delay"));
const autobind_decorator_1 = require("autobind-decorator");
const aws_sdk_1 = require("../Tracer/aws-sdk");
const client_secrets_manager_1 = require("@aws-sdk/client-secrets-manager");
class AWSSecretsManager {
    constructor(localCache, defaultRegion) {
        this.localCache = localCache;
        this.defaultRegion = defaultRegion;
    }
    async getSecret(SecretId, region) {
        if (!this.defaultRegion && !region)
            throw new TypeError('No region or default region provided');
        const client = new client_secrets_manager_1.SecretsManagerClient({ region: this.defaultRegion || region });
        client.middlewareStack.add(aws_sdk_1.awsSdkTracer, aws_sdk_1.TRACING_MIDDLEWARE_CONFIG);
        const { SecretString } = await client.send(new client_secrets_manager_1.GetSecretValueCommand({ SecretId }));
        return JSON.parse(SecretString);
    }
    async get(secretName, region) {
        const cacheKey = this.getCacheKey(secretName, region);
        const statusCacheKey = this.getStatusCacheKey(secretName, region);
        let status = this.localCache.get(statusCacheKey);
        let secret = this.localCache.get(cacheKey);
        while (!secret && status === 'pending') {
            await delay_1.default(30);
            status = this.localCache.get(statusCacheKey);
            secret = this.localCache.get(cacheKey);
        }
        if (secret)
            return secret;
        this.localCache.set(statusCacheKey, 'pending');
        try {
            secret = await this.getSecret(secretName, region);
            this.localCache.set(cacheKey, secret);
            this.localCache.set(statusCacheKey, 'done');
            return secret;
        }
        catch (e) {
            this.localCache.set(statusCacheKey, undefined);
            throw e;
        }
    }
    async refresh(secretName, region) {
        const cacheKey = this.getCacheKey(secretName, region);
        const statusCacheKey = this.getStatusCacheKey(secretName, region);
        this.localCache.set(statusCacheKey, undefined);
        this.localCache.set(cacheKey, undefined);
        await this.get(secretName, region);
    }
    getCacheKey(secretName, region) {
        const awsRegion = this.defaultRegion || region;
        return `x-ts-sec-${awsRegion}-W9SA1kJeoJ-${secretName}`;
    }
    getStatusCacheKey(secretName, region) {
        const awsRegion = this.defaultRegion || region;
        return `x-ts-sec-stt-${awsRegion}-W9SA1kJeoJ-${secretName}`;
    }
}
__decorate([
    autobind_decorator_1.boundMethod
], AWSSecretsManager.prototype, "getSecret", null);
__decorate([
    autobind_decorator_1.boundMethod
], AWSSecretsManager.prototype, "get", null);
__decorate([
    autobind_decorator_1.boundMethod
], AWSSecretsManager.prototype, "refresh", null);
__decorate([
    autobind_decorator_1.boundMethod
], AWSSecretsManager.prototype, "getCacheKey", null);
__decorate([
    autobind_decorator_1.boundMethod
], AWSSecretsManager.prototype, "getStatusCacheKey", null);
exports.AWSSecretsManager = AWSSecretsManager;
