/**
 * refer to https://github.com/open-telemetry/opentelemetry-specification/tree/main/specification/trace/semantic_conventions
 */
export declare const ATTRIBUTES: {
    NET_TRANSPORT: string;
    NET_PEER_IP: string;
    NET_PEER_PORT: string;
    NET_PEER_NAME: string;
    NET_HOST_IP: string;
    NET_HOST_PORT: string;
    NET_HOST_NAME: string;
    PEER_SERVICE: string;
    ENDUSER_ID: string;
    ENDUSER_ROLE: string;
    ENDUSER_SCOPE: string;
    CODE_FUNCTION: string;
    CODE_NAMESPACE: string;
    CODE_FILEPATH: string;
    CODE_LINENO: string;
    HTTP_METHOD: string;
    HTTP_URL: string;
    HTTP_TARGET: string;
    HTTP_HOST: string;
    HTTP_SCHEME: string;
    HTTP_STATUS_CODE: string;
    HTTP_FLAVOR: string;
    HTTP_USER_AGENT: string;
    HTTP_REQUEST_CONTENT_LENGTH: string;
    HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED: string;
    HTTP_RESPONSE_CONTENT_LENGTH: string;
    HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED: string;
    HTTP_SERVER_NAME: string;
    HTTP_ROUTE: string;
    HTTP_CLIENT_IP: string;
    DB_SYSTEM: string;
    DB_CONNECTION_STRING: string;
    DB_USER: string;
    DB_NAME: string;
    DB_STATEMENT: string;
    DB_OPERATION: string;
    RPC_SYSTEM: string;
    RPC_SERVICE: string;
    RPC_METHOD: string;
    MESSAGING_SYSTEM: string;
    MESSAGING_DESTINATION: string;
    MESSAGING_DESTINATION_KIND: string;
    MESSAGING_TEMP_DESTINATION: string;
    MESSAGING_OPERATION: string;
    MESSAGING_PROTOCOL: string;
    MESSAGING_PROTOCOL_VERSION: string;
    MESSAGING_URL: string;
    MESSAGING_MESSAGE_ID: string;
    MESSAGING_CONVERSATION_ID: string;
    MESSAGING_MESSAGE_PAYLOAD_SIZE_BYTES: string;
    MESSAGING_MESSAGE_PAYLOAD_COMPRESSED_SIZE_BYTES: string;
    FAAS_TRIGGER: string;
    FAAS_EXECUTION: string;
    FAAS_INVOKED_NAME: string;
    FAAS_INVOKED_PROVIDER: string;
    FAAS_INVOKED_REGION: string;
    FAAS_DOCUMENT_COLLECTION: string;
    FAAS_DOCUMENT_OPERATION: string;
    FAAS_DOCUMENT_TIME: string;
    FAAS_DOCUMENT_NAME: string;
    FAAS_TIME: string;
    FAAS_CRON: string;
    EXCEPTION_TYPE: string;
    EXCEPTION_MESSAGE: string;
    EXCEPTION_STACKTRACE: string;
    EXCEPTION_ESCAPED: string;
};
export declare const VALUES: {
    NET_TRANSPORT: {
        IP_TCP: string;
        IP_UDP: string;
        IP: string;
        UNIX: string;
        PIPE: string;
        INPROC: string;
        OTHER: string;
    };
    HTTP_FLAVOR: {
        HTTP_1_0: string;
        HTTP_1_1: string;
        HTTP_2_0: string;
        SPDY: string;
        QUIC: string;
    };
    DB_SYSTEM: {
        OTHER_SQL: string;
        MSSQL: string;
        MYSQL: string;
        ORACLE: string;
        DB2: string;
        POSTGRESQL: string;
        REDSHIFT: string;
        HIVE: string;
        CLOUDSCAPE: string;
        HSQLDB: string;
        PROGRESS: string;
        MAXDB: string;
        HANADB: string;
        INGRES: string;
        FIRSTSQL: string;
        EDB: string;
        CACHE: string;
        ADABAS: string;
        FIREBIRD: string;
        DERBY: string;
        FILEMAKER: string;
        INFORMIX: string;
        INSTANTDB: string;
        INTERBASE: string;
        MARIADB: string;
        NETEZZA: string;
        PERVASIVE: string;
        POINTBASE: string;
        SQLITE: string;
        SYBASE: string;
        TERADATA: string;
        VERTICA: string;
        H2: string;
        COLDFUSION: string;
        CASSANDRA: string;
        HBASE: string;
        MONGODB: string;
        REDIS: string;
        COUCHBASE: string;
        COUCHDB: string;
        COSMOSDB: string;
        DYNAMODB: string;
        NEO4J: string;
        GEODE: string;
        ELASTICSEARCH: string;
        MEMCACHED: string;
    };
    MESSAGING_OPERATION: {
        SEND: string;
        RECEIVE: string;
        PROCESS: string;
    };
    MESSAGING_DESTINATION_KIND: {
        QUEUE: string;
        TOPIC: string;
    };
    FAAS_TRIGGER: {
        DATASOURCE: string;
        HTTP: string;
        PUBSUB: string;
        TIMER: string;
        OTHER: string;
    };
    FAAS_DOCUMENT_OPERATION: {
        INSERT: string;
        EDIT: string;
        DELETE: string;
    };
};
