"use strict";
/**
 * refer to https://github.com/open-telemetry/opentelemetry-specification/tree/main/specification/trace/semantic_conventions
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.VALUES = exports.ATTRIBUTES = void 0;
exports.ATTRIBUTES = {
    NET_TRANSPORT: 'net.transport',
    NET_PEER_IP: 'net.peer.ip',
    NET_PEER_PORT: 'net.peer.port',
    NET_PEER_NAME: 'net.peer.name',
    NET_HOST_IP: 'net.host.ip',
    NET_HOST_PORT: 'net.host.port',
    NET_HOST_NAME: 'net.host.name',
    PEER_SERVICE: 'peer.service',
    ENDUSER_ID: 'enduser.id',
    ENDUSER_ROLE: 'enduser.role',
    ENDUSER_SCOPE: 'enduser.scope',
    CODE_FUNCTION: 'code.function',
    CODE_NAMESPACE: 'code.namespace',
    CODE_FILEPATH: 'code.filepath',
    CODE_LINENO: 'code.lineno',
    HTTP_METHOD: 'http.method',
    HTTP_URL: 'http.url',
    HTTP_TARGET: 'http.target',
    HTTP_HOST: 'http.host',
    HTTP_SCHEME: 'http.scheme',
    HTTP_STATUS_CODE: 'http.status_code',
    HTTP_FLAVOR: 'http.flavor',
    HTTP_USER_AGENT: 'http.user_agent',
    HTTP_REQUEST_CONTENT_LENGTH: 'http.request_content_length',
    HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED: 'http.request_content_length_uncompressed',
    HTTP_RESPONSE_CONTENT_LENGTH: 'http.response_content_length',
    HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED: 'http.response_content_length_uncompressed',
    HTTP_SERVER_NAME: 'http.server_name',
    HTTP_ROUTE: 'http.route',
    HTTP_CLIENT_IP: 'http.client_ip',
    DB_SYSTEM: 'db.system',
    DB_CONNECTION_STRING: 'db.connection_string',
    DB_USER: 'db.user',
    DB_NAME: 'db.name',
    DB_STATEMENT: 'db.statement',
    DB_OPERATION: 'db.operation',
    RPC_SYSTEM: 'rpc.system',
    RPC_SERVICE: 'rpc.service',
    RPC_METHOD: 'rpc.method',
    MESSAGING_SYSTEM: 'messaging.system',
    MESSAGING_DESTINATION: 'messaging.destination',
    MESSAGING_DESTINATION_KIND: 'messaging.destination_kind',
    MESSAGING_TEMP_DESTINATION: 'messaging.temp_destination',
    MESSAGING_OPERATION: 'messaging.operation',
    MESSAGING_PROTOCOL: 'messaging.protocol',
    MESSAGING_PROTOCOL_VERSION: 'messaging.protocol_version',
    MESSAGING_URL: 'messaging.url',
    MESSAGING_MESSAGE_ID: 'messaging.message_id',
    MESSAGING_CONVERSATION_ID: 'messaging.conversation_id',
    MESSAGING_MESSAGE_PAYLOAD_SIZE_BYTES: 'messaging.message_payload_size_bytes',
    MESSAGING_MESSAGE_PAYLOAD_COMPRESSED_SIZE_BYTES: 'messaging.message_payload_compressed_size_bytes',
    FAAS_TRIGGER: 'faas.trigger',
    FAAS_EXECUTION: 'faas.execution',
    FAAS_INVOKED_NAME: 'faas.invoked_name',
    FAAS_INVOKED_PROVIDER: 'faas.invoked_provider',
    FAAS_INVOKED_REGION: 'faas.invoked_region',
    FAAS_DOCUMENT_COLLECTION: 'faas.document.collection',
    FAAS_DOCUMENT_OPERATION: 'faas.document.operation',
    FAAS_DOCUMENT_TIME: 'faas.document.time',
    FAAS_DOCUMENT_NAME: 'faas.document.name',
    FAAS_TIME: 'faas.time',
    FAAS_CRON: 'faas.cron',
    EXCEPTION_TYPE: 'exception.type',
    EXCEPTION_MESSAGE: 'exception.message',
    EXCEPTION_STACKTRACE: 'exception.stacktrace',
    EXCEPTION_ESCAPED: 'exception.escaped',
};
exports.VALUES = {
    NET_TRANSPORT: {
        IP_TCP: 'ip_tcp',
        IP_UDP: 'ip_udp',
        IP: 'ip',
        UNIX: 'unix',
        PIPE: 'pipe',
        INPROC: 'inproc',
        OTHER: 'other',
    },
    HTTP_FLAVOR: {
        HTTP_1_0: '1.0',
        HTTP_1_1: '1.1',
        HTTP_2_0: '2.0',
        SPDY: 'SPDY',
        QUIC: 'QUIC',
    },
    DB_SYSTEM: {
        OTHER_SQL: 'other_sql',
        MSSQL: 'mssql',
        MYSQL: 'mysql',
        ORACLE: 'oracle',
        DB2: 'db2',
        POSTGRESQL: 'postgresql',
        REDSHIFT: 'redshift',
        HIVE: 'hive',
        CLOUDSCAPE: 'cloudscape',
        HSQLDB: 'hsqldb',
        PROGRESS: 'progress',
        MAXDB: 'maxdb',
        HANADB: 'hanadb',
        INGRES: 'ingres',
        FIRSTSQL: 'firstsql',
        EDB: 'edb',
        CACHE: 'cache',
        ADABAS: 'adabas',
        FIREBIRD: 'firebird',
        DERBY: 'derby',
        FILEMAKER: 'filemaker',
        INFORMIX: 'informix',
        INSTANTDB: 'instantdb',
        INTERBASE: 'interbase',
        MARIADB: 'mariadb',
        NETEZZA: 'netezza',
        PERVASIVE: 'pervasive',
        POINTBASE: 'pointbase',
        SQLITE: 'sqlite',
        SYBASE: 'sybase',
        TERADATA: 'teradata',
        VERTICA: 'vertica',
        H2: 'h2',
        COLDFUSION: 'coldfusion',
        CASSANDRA: 'cassandra',
        HBASE: 'hbase',
        MONGODB: 'mongodb',
        REDIS: 'redis',
        COUCHBASE: 'couchbase',
        COUCHDB: 'couchdb',
        COSMOSDB: 'cosmosdb',
        DYNAMODB: 'dynamodb',
        NEO4J: 'neo4j',
        GEODE: 'geode',
        ELASTICSEARCH: 'elasticsearch',
        MEMCACHED: 'memcached',
    },
    MESSAGING_OPERATION: {
        SEND: 'send',
        RECEIVE: 'receive',
        PROCESS: 'process',
    },
    MESSAGING_DESTINATION_KIND: {
        QUEUE: 'queue',
        TOPIC: 'topic',
    },
    FAAS_TRIGGER: {
        DATASOURCE: 'datasource',
        HTTP: 'http',
        PUBSUB: 'pubsub',
        TIMER: 'timer',
        OTHER: 'other',
    },
    FAAS_DOCUMENT_OPERATION: {
        INSERT: 'insert',
        EDIT: 'edit',
        DELETE: 'delete',
    },
};
