"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TRACING_MIDDLEWARE_CONFIG = exports.awsSdkTracer = void 0;
const api_1 = __importDefault(require("@opentelemetry/api"));
const attributes_1 = require("./attributes");
function awsSdkTracer(next, context) {
    return async (args) => {
        const { clientName, commandName } = context;
        const service = clientName || 'unknown';
        const method = commandName || 'unknown';
        const span = getSpan(service, method, args);
        try {
            const res = await next(args);
            span.end();
            return res;
        }
        catch (error) {
            span.recordException(error);
            span.end();
            throw error;
        }
    };
}
exports.awsSdkTracer = awsSdkTracer;
function getSpan(service, method, args) {
    const tracer = api_1.default.trace.getTracer('aws-sdk');
    const span = tracer.startSpan(`${service}.${method}`);
    span.setAttribute(attributes_1.ATTRIBUTES.RPC_SERVICE, service);
    span.setAttribute(attributes_1.ATTRIBUTES.RPC_METHOD, method);
    span.setAttribute(attributes_1.ATTRIBUTES.RPC_SYSTEM, 'aws-api');
    if (service === 'SecretsManagerClient' && method === 'GetSecretValueCommand') {
        const { SecretId } = args.input;
        if (SecretId)
            span.setAttribute('aws.secretsmanager.secret_id', SecretId);
    }
    if (service === 'DynamoDBClient') {
        span.setAttribute(attributes_1.ATTRIBUTES.DB_SYSTEM, attributes_1.VALUES.DB_SYSTEM.DYNAMODB);
        const { TableName, RequestItems } = args.input;
        if (typeof TableName === 'string')
            span.setAttribute('aws.dynamodb.table_name', TableName);
        if (RequestItems && typeof RequestItems === 'object') {
            const tableNames = Object.keys(RequestItems);
            if (typeof TableName === 'string')
                span.setAttribute('aws.dynamodb.table_name', tableNames.join(','));
        }
    }
    return span;
}
exports.TRACING_MIDDLEWARE_CONFIG = {
    step: 'build',
    name: 'tks-otel-tracer',
    tags: ['OTEL', 'TKS'],
};
