"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.attachAxiosTracer = void 0;
const attributes_1 = require("./attributes");
const api_1 = __importDefault(require("@opentelemetry/api"));
function attachAxiosTracer(axiosInstance) {
    if (!axiosInstance)
        throw new TypeError('axios instance required!');
    axiosInstance.interceptors.request.use(RequestInterceptor, RequestErrorInterceptor);
    axiosInstance.interceptors.response.use(ResponseSuccessInterceptor, ResponseErrorInterceptor);
}
exports.attachAxiosTracer = attachAxiosTracer;
function RequestInterceptor(config) {
    const tracer = api_1.default.trace.getTracer('axios');
    const { method, baseURL, url } = config;
    try {
        const fullURL = `${baseURL || ''}${url}`;
        const span = tracer.startSpan(`HTTP ${method?.toUpperCase()}`);
        span.setAttribute(attributes_1.ATTRIBUTES.HTTP_METHOD, method?.toUpperCase());
        span.setAttribute(attributes_1.ATTRIBUTES.HTTP_URL, fullURL);
        const ctx = api_1.default.context.active();
        api_1.default.propagation.inject(ctx, config.headers);
        config.span = span;
    }
    catch (e) { }
    return config;
}
function RequestErrorInterceptor(error) {
    if (error.config && error.config.span) {
        const { span } = error.config;
        try {
            span.recordException('error in request');
            span.end();
        }
        catch (e) { }
    }
    return Promise.reject(error);
}
function ResponseSuccessInterceptor(response) {
    if (response.config && response.config.span) {
        const { span } = response.config;
        try {
            span.setAttribute(attributes_1.ATTRIBUTES.HTTP_STATUS_CODE, response.status);
            span.end();
        }
        catch (e) { }
    }
    return response;
}
function ResponseErrorInterceptor(error) {
    if (error.config && error.config.span) {
        const { span } = error.config;
        try {
            span.recordException('error in response');
            const status = error.code || error.response?.status;
            if (status)
                span.setAttribute(attributes_1.ATTRIBUTES.HTTP_STATUS_CODE, status);
            span.end();
        }
        catch (e) { }
    }
    return Promise.reject(error);
}
