"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.traceOracleDbConnection = void 0;
const api_1 = __importDefault(require("@opentelemetry/api"));
const attributes_1 = require("./attributes");
function traceOracleDbConnection(connection) {
    const tracer = api_1.default.trace.getTracer('oracleDb');
    return new Proxy(connection, {
        get(target, propKey) {
            const origPropOrMethod = target[propKey];
            if (propKey === 'execute') {
                const origMethod = target[propKey];
                return async function (...args) {
                    if (args.every((arg) => typeof arg !== 'function')) {
                        const span = tracer.startSpan(`ORACLE DB`);
                        span.setAttribute(attributes_1.ATTRIBUTES.DB_SYSTEM, attributes_1.VALUES.DB_SYSTEM.ORACLE);
                        span.setAttribute(attributes_1.ATTRIBUTES.DB_STATEMENT, args[0]);
                        try {
                            const result = await origMethod.apply(connection, args);
                            span.end();
                            return result;
                        }
                        catch (error) {
                            span.recordException(error);
                            span.end();
                            throw error;
                        }
                    }
                    else {
                        return origMethod.apply(connection, args);
                    }
                };
            }
            else if (typeof origPropOrMethod === 'function') {
                return function (...args) {
                    return origPropOrMethod.apply(connection, args);
                };
            }
            else {
                return Reflect.get(target, propKey);
            }
        },
    });
}
exports.traceOracleDbConnection = traceOracleDbConnection;
