"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withSpan = exports.Trace = exports.getTraced = void 0;
const attributes_1 = require("./attributes");
const api_1 = __importStar(require("@opentelemetry/api"));
function getTraced(spanNameOrOption, fn) {
    return (async (...args) => await withSpan(spanNameOrOption, () => fn(...args)));
}
exports.getTraced = getTraced;
function Trace(spanNameOrOption) {
    return (_target, _propertyKey, descriptor) => {
        const originalMethod = descriptor.value;
        descriptor.value = async function (...args) {
            return await withSpan(spanNameOrOption, () => originalMethod.apply(this, args));
        };
    };
}
exports.Trace = Trace;
async function withSpan(spanNameOrOption, fn) {
    let name;
    let attributes;
    let attributesOnReject;
    let attributesOnResolve;
    if (typeof spanNameOrOption === 'string') {
        name = spanNameOrOption;
        attributes = undefined;
        attributesOnReject = undefined;
        attributesOnResolve = undefined;
    }
    else {
        name = spanNameOrOption.name;
        attributes = spanNameOrOption.attributes;
        attributesOnReject = spanNameOrOption.attributesOnReject;
        attributesOnResolve = spanNameOrOption.attributesOnResolve;
    }
    const tracer = api_1.default.trace.getTracer('default');
    const span = tracer.startSpan(name);
    if (attributes)
        span.setAttributes(attributes);
    return new Promise((resolve, reject) => {
        api_1.default.context.with(api_1.setSpan(api_1.default.context.active(), span), async () => {
            try {
                const res = await fn(span);
                if (attributesOnResolve)
                    span.setAttributes(attributesOnResolve);
                span.end();
                resolve(res);
            }
            catch (e) {
                if (e instanceof Error) {
                    span.recordException(e);
                }
                else {
                    span.setAttribute('error', true);
                    span.setAttribute(attributes_1.ATTRIBUTES.EXCEPTION_MESSAGE, String(e));
                }
                if (attributesOnReject)
                    span.setAttributes(attributesOnReject);
                span.end();
                reject(e);
            }
        });
    });
}
exports.withSpan = withSpan;
